@@ -4,4 +4,6 @@ mod github;
 
 pub use config::config_github;
 pub use data_structures::*;
-pub use github::repo;
\ No newline at end of file
+pub use github::repo;
+pub use github::check_merge_methods;
+pub use github::check_states;
\ No newline at end of file
